==> ukui-sidebar_3.0.0.orig.tar.gz: ukui-sidebar/translations/ukui-sidebar_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>QObject</name>
    <message>
        <location filename="main.cpp" line="60"/>
        <source>Display debug information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="widget.cpp" line="182"/>
        <source>Open</source>
        <translation>打开</translation>
    </message>
    <message>
        <location filename="widget.cpp" line="185"/>
        <source>Set up notification center</source>
        <translation>设置通知中心</translation>
    </message>
</context>
<context>
    <name>Widget</name>
    <message>
        <source>ClipBoard</source>
        <translation type="vanished">剪贴板</translation>
    </message>
    <message>
        <location filename="widget.cpp" line="218"/>
        <source>Sidebar</source>
        <translation>侧边栏</translation>
    </message>
</context>
<context>
    <name>sidebarPluginsWidgets</name>
    <message>
        <location filename="sidebarpluginswidgets.cpp" line="92"/>
        <source>Clipboard</source>
        <translation>剪贴板</translation>
    </message>
    <message>
        <location filename="sidebarpluginswidgets.cpp" line="98"/>
        <source>Plugins</source>
        <translation>小插件</translation>
    </message>
    <message>
        <source>Notebook</source>
        <translation type="vanished">笔记本</translation>
    </message>
    <message>
        <source>Alarm clock</source>
        <translation type="vanished">闹钟</translation>
    </message>
    <message>
        <source>Feedback</source>
        <translation type="vanished">用户反馈</translation>
    </message>
</context>
</TS>

==> ukui-sidebar_3.1.1.orig.tar.gz: ukui-sidebar/translations/ukui-sidebar_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main.cpp" line="81"/>
        <source>Display debug information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/widget.cpp" line="177"/>
        <source>Open</source>
        <translation>打开</translation>
    </message>
    <message>
        <location filename="../src/widget.cpp" line="180"/>
        <source>Set up notification center</source>
        <translation>设置通知中心</translation>
    </message>
    <message>
        <location filename="../src/sidebarpluginswidgets.cpp" line="112"/>
        <source>折叠</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/sidebarpluginswidgets.cpp" line="114"/>
        <source>展开</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Widget</name>
    <message>
        <source>ClipBoard</source>
        <translation type="vanished">剪贴板</translation>
    </message>
    <message>
        <location filename="../src/widget.cpp" line="210"/>
        <source>Sidebar</source>
        <translation>侧边栏</translation>
    </message>
</context>
<context>
    <name>sidebarPluginsWidgets</name>
    <message>
        <location filename="../src/sidebarpluginswidgets.cpp" line="97"/>
        <source>Clipboard</source>
        <translation>剪贴板</translation>
    </message>
    <message>
        <location filename="../src/sidebarpluginswidgets.cpp" line="104"/>
        <source>Plugins</source>
        <translation>小插件</translation>
    </message>
    <message>
        <source>Notebook</source>
        <translation type="vanished">笔记本</translation>
    </message>
    <message>
        <source>Alarm clock</source>
        <translation type="vanished">闹钟</translation>
    </message>
    <message>
        <source>Feedback</source>
        <translation type="vanished">用户反馈</translation>
    </message>
</context>
</TS>
